@@ -28,7 +28,7 @@ class ExpData : public SimulationParameters {
      * @brief Copy constructor, needs to be declared to be generated in
      * swig
      */
-    ExpData(const ExpData &) = default;
+    ExpData(ExpData const&) = default;
 
     /**
      * @brief constructor that only initializes dimensions
@@ -88,7 +88,7 @@ class ExpData : public SimulationParameters {
      *
      * @param model pointer to model specification object
      */
-    explicit ExpData(const Model &model);
+    explicit ExpData(Model const& model);
 
     /**
      * @brief constructor that initializes with returnData, adds noise according
@@ -98,7 +98,7 @@ class ExpData : public SimulationParameters {
      * @param sigma_y scalar standard deviations for all observables
      * @param sigma_z scalar standard deviations for all event observables
      */
-    ExpData(const ReturnData &rdata, realtype sigma_y, realtype sigma_z);
+    ExpData(ReturnData const& rdata, realtype sigma_y, realtype sigma_z);
 
     /**
      * @brief constructor that initializes with returnData, adds noise according
@@ -110,12 +110,14 @@ class ExpData : public SimulationParameters {
      * @param sigma_z vector of standard deviations for event observables
      * (dimension: nztrue or nmaxevent x nztrue, row-major)
      */
-    ExpData(const ReturnData &rdata, std::vector<realtype> sigma_y,
-            std::vector<realtype> sigma_z);
+    ExpData(
+        ReturnData const& rdata, std::vector<realtype> sigma_y,
+        std::vector<realtype> sigma_z
+    );
 
     ~ExpData() = default;
 
-    friend inline bool operator==(const ExpData& lhs, const ExpData& rhs);
+    friend inline bool operator==(ExpData const& lhs, ExpData const& rhs);
 
     /**
      * @brief number of observables of the non-augmented model
@@ -150,7 +152,7 @@ class ExpData : public SimulationParameters {
      *
      * @param ts timepoints
      */
-    void setTimepoints(const std::vector<realtype> &ts);
+    void setTimepoints(std::vector<realtype> const& ts);
 
     /**
      * @brief get function that copies data from ExpData::ts to output
@@ -173,7 +175,7 @@ class ExpData : public SimulationParameters {
      *
      * @param observedData observed data (dimension: nt x nytrue, row-major)
      */
-    void setObservedData(const std::vector<realtype> &observedData);
+    void setObservedData(std::vector<realtype> const& observedData);
 
     /**
      * @brief set function that copies observed data for specific observable
@@ -181,7 +183,7 @@ class ExpData : public SimulationParameters {
      * @param observedData observed data (dimension: nt)
      * @param iy observed data index
      */
-    void setObservedData(const std::vector<realtype> &observedData, int iy);
+    void setObservedData(std::vector<realtype> const& observedData, int iy);
 
     /**
      * @brief get function that checks whether data at specified indices has
@@ -208,7 +210,7 @@ class ExpData : public SimulationParameters {
      *
      * @return pointer to observed data at index (dimension: nytrue)
      */
-    const realtype *getObservedDataPtr(int it) const;
+    realtype const* getObservedDataPtr(int it) const;
 
     /**
      * @brief set function that copies data from input to
@@ -217,7 +219,7 @@ class ExpData : public SimulationParameters {
      * @param observedDataStdDev standard deviation of observed data (dimension:
      * nt x nytrue, row-major)
      */
-    void setObservedDataStdDev(const std::vector<realtype> &observedDataStdDev);
+    void setObservedDataStdDev(std::vector<realtype> const& observedDataStdDev);
 
     /**
      * @brief set function that sets all ExpData::observedDataStdDev to the
@@ -235,8 +237,9 @@ class ExpData : public SimulationParameters {
      * nt)
      * @param iy observed data index
      */
-    void setObservedDataStdDev(const std::vector<realtype> &observedDataStdDev,
-                               int iy);
+    void setObservedDataStdDev(
+        std::vector<realtype> const& observedDataStdDev, int iy
+    );
 
     /**
      * @brief set function that sets all standard deviation of a specific
@@ -272,7 +275,7 @@ class ExpData : public SimulationParameters {
      * @param it timepoint index
      * @return pointer to standard deviation of observed data at index
      */
-    const realtype *getObservedDataStdDevPtr(int it) const;
+    realtype const* getObservedDataStdDevPtr(int it) const;
 
     /**
      * @brief set function that copies observed event data from input to
@@ -281,7 +284,7 @@ class ExpData : public SimulationParameters {
      * @param observedEvents observed data (dimension: nmaxevent x nztrue,
      * row-major)
      */
-    void setObservedEvents(const std::vector<realtype> &observedEvents);
+    void setObservedEvents(std::vector<realtype> const& observedEvents);
 
     /**
      * @brief set function that copies observed event data for specific event
@@ -290,7 +293,7 @@ class ExpData : public SimulationParameters {
      * @param observedEvents observed data (dimension: nmaxevent)
      * @param iz observed event data index
      */
-    void setObservedEvents(const std::vector<realtype> &observedEvents, int iz);
+    void setObservedEvents(std::vector<realtype> const& observedEvents, int iz);
 
     /**
      * @brief get function that checks whether event data at specified indices
@@ -317,7 +320,7 @@ class ExpData : public SimulationParameters {
      *
      * @return pointer to observed event data at ieth occurrence
      */
-    const realtype *getObservedEventsPtr(int ie) const;
+    realtype const* getObservedEventsPtr(int ie) const;
 
     /**
      * @brief set function that copies data from input to
@@ -326,7 +329,7 @@ class ExpData : public SimulationParameters {
      * @param observedEventsStdDev standard deviation of observed event data
      */
     void
-    setObservedEventsStdDev(const std::vector<realtype> &observedEventsStdDev);
+    setObservedEventsStdDev(std::vector<realtype> const& observedEventsStdDev);
 
     /**
      * @brief set function that sets all ExpData::observedDataStdDev to the
@@ -344,9 +347,9 @@ class ExpData : public SimulationParameters {
      * (dimension: nmaxevent)
      * @param iz observed data index
      */
-    void
-    setObservedEventsStdDev(const std::vector<realtype> &observedEventsStdDev,
-                            int iz);
+    void setObservedEventsStdDev(
+        std::vector<realtype> const& observedEventsStdDev, int iz
+    );
 
     /**
      * @brief set function that sets all standard deviation of a specific
@@ -384,7 +387,7 @@ class ExpData : public SimulationParameters {
      * @return pointer to standard deviation of observed event data at ie-th
      * occurrence
      */
-    const realtype *getObservedEventsStdDevPtr(int ie) const;
+    realtype const* getObservedEventsStdDevPtr(int ie) const;
 
     /**
      * @brief Arbitrary (not necessarily unique) identifier.
@@ -414,8 +417,9 @@ class ExpData : public SimulationParameters {
      * @param input vector input to be checked
      * @param fieldname name of the input
      */
-    void checkDataDimension(std::vector<realtype> const &input,
-                            const char *fieldname) const;
+    void checkDataDimension(
+        std::vector<realtype> const& input, char const* fieldname
+    ) const;
 
     /**
      * @brief checker for dimensions of input observedEvents or
@@ -424,8 +428,9 @@ class ExpData : public SimulationParameters {
      * @param input vector input to be checked
      * @param fieldname name of the input
      */
-    void checkEventsDimension(std::vector<realtype> const &input,
-                              const char *fieldname) const;
+    void checkEventsDimension(
+        std::vector<realtype> const& input, char const* fieldname
+    ) const;
 
     /** @brief number of observables */
     int nytrue_{0};
@@ -457,33 +462,34 @@ class ExpData : public SimulationParameters {
     std::vector<realtype> observed_events_std_dev_;
 };
 
-
-inline bool operator==(const ExpData& lhs, const ExpData& rhs) {
-    return *dynamic_cast< const SimulationParameters* >(&lhs)
-               == *dynamic_cast< const SimulationParameters* >(&rhs)
-           && lhs.id == rhs.id
-           && lhs.nytrue_ == rhs.nytrue_
-           && lhs.nztrue_ == rhs.nztrue_
-           && lhs.nmaxevent_ == rhs.nmaxevent_
-           && is_equal(lhs.observed_data_,
-                       rhs.observed_data_)
-           && is_equal(lhs.observed_data_std_dev_,
-                       rhs.observed_data_std_dev_)
-           && is_equal(lhs.observed_events_,
-                       rhs.observed_events_)
-           && is_equal(lhs.observed_events_std_dev_,
-                       rhs.observed_events_std_dev_);
+/**
+ * @brief Equality operator
+ * @param lhs some object
+ * @param rhs another object
+ * @return `true`, if both arguments are equal; `false` otherwise.
+ */
+inline bool operator==(ExpData const& lhs, ExpData const& rhs) {
+    return *dynamic_cast<SimulationParameters const*>(&lhs)
+               == *dynamic_cast<SimulationParameters const*>(&rhs)
+           && lhs.id == rhs.id && lhs.nytrue_ == rhs.nytrue_
+           && lhs.nztrue_ == rhs.nztrue_ && lhs.nmaxevent_ == rhs.nmaxevent_
+           && is_equal(lhs.observed_data_, rhs.observed_data_)
+           && is_equal(lhs.observed_data_std_dev_, rhs.observed_data_std_dev_)
+           && is_equal(lhs.observed_events_, rhs.observed_events_)
+           && is_equal(
+               lhs.observed_events_std_dev_, rhs.observed_events_std_dev_
+           );
 };
 
-
 /**
  * @brief checks input vector of sigmas for not strictly positive values
  *
  * @param sigmaVector vector input to be checked
  * @param vectorName name of the input
  */
-void checkSigmaPositivity(std::vector<realtype> const &sigmaVector,
-                          const char *vectorName);
+void checkSigmaPositivity(
+    std::vector<realtype> const& sigmaVector, char const* vectorName
+);
 
 /**
  * @brief checks input scalar sigma for not strictly positive value
@@ -491,7 +497,7 @@ void checkSigmaPositivity(std::vector<realtype> const &sigmaVector,
  * @param sigma input to be checked
  * @param sigmaName name of the input
  */
-void checkSigmaPositivity(realtype sigma, const char *sigmaName);
+void checkSigmaPositivity(realtype sigma, char const* sigmaName);
 
 /**
  * @brief The ConditionContext class applies condition-specific amici::Model
@@ -508,10 +514,11 @@ class ConditionContext : public ContextManager {
      * @param fpc flag indicating which fixedParameter from edata to apply
      */
     explicit ConditionContext(
-        Model *model, const ExpData *edata = nullptr,
-        FixedParameterContext fpc = FixedParameterContext::simulation);
+        Model* model, ExpData const* edata = nullptr,
+        FixedParameterContext fpc = FixedParameterContext::simulation
+    );
 
-    ConditionContext &operator=(const ConditionContext &other) = delete;
+    ConditionContext& operator=(ConditionContext const& other) = delete;
 
     ~ConditionContext();
 
@@ -523,8 +530,7 @@ class ConditionContext : public ContextManager {
      * @param edata
      * @param fpc flag indicating which fixedParameter from edata to apply
      */
-    void applyCondition(const ExpData *edata,
-                        FixedParameterContext fpc);
+    void applyCondition(ExpData const* edata, FixedParameterContext fpc);
 
     /**
      * @brief Restore original settings on constructor-supplied amici::Model.
